@@ -13,7 +13,7 @@ use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 package XML::Ant::BuildFile::Resource;
 
 BEGIN {
-    $XML::Ant::BuildFile::Resource::VERSION = '0.209';
+    $XML::Ant::BuildFile::Resource::VERSION = '0.210';
 }
 
 # ABSTRACT: Role for Ant build file resources
@@ -22,24 +22,57 @@ use strict;
 use English '-no_match_vars';
 use Moose::Role;
 use MooseX::Has::Sugar;
-use MooseX::Types::Moose 'Str';
+use MooseX::Types::Moose qw(Maybe Str);
 use namespace::autoclean;
 with 'XML::Ant::BuildFile::Role::InProject';
 
-requires 'as_string';
-
 has resource_name => ( ro, lazy,
     isa      => Str,
     init_arg => undef,
     default  => sub { $ARG[0]->node->nodeName },
 );
 
+requires qw(as_string content);
+
+around as_string => sub {
+    my ( $orig, $self ) = splice @ARG, 0, 2;
+    return $self->$orig(@ARG) if !$self->_refid;
+
+    my $antecedent = $self->project->find_resource(
+        sub {
+            $ARG->resource_name eq $self->resource_name
+                and $ARG->id eq $self->_refid;
+        }
+    );
+    return $antecedent->as_string;
+};
+
 {
 ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
     has id =>
         ( ro, isa => Str, traits => ['XPathValue'], xpath_query => './@id' );
+    has _refid => ( ro,
+        isa         => Str,
+        traits      => ['XPathValue'],
+        xpath_query => './@refid',
+    );
 }
 
+has content => ( ro, lazy_build, isa => Maybe );
+
+around content => sub {
+    my ( $orig, $self ) = splice @ARG, 0, 2;
+    return $self->$orig(@ARG) if !$self->_refid;
+
+    my $antecedent = $self->project->find_resource(
+        sub {
+            $ARG->resource_name eq $self->resource_name
+                and $ARG->id eq $self->_refid;
+        }
+    );
+    return $antecedent->content;
+};
+
 sub BUILD {
     my $self = shift;
     if ( $self->id ) {
@@ -63,7 +96,7 @@ XML::Ant::BuildFile::Resource - Role for Ant build file resources
 
 =head1 VERSION
 
-version 0.209
+version 0.210
 
 =head1 SYNOPSIS
 
@@ -85,10 +118,6 @@ L<XML::Ant::BuildFile::Project|XML::Ant::BuildFile::Project>.
 
 =head1 ATTRIBUTES
 
-=head2 as_string
-
-Every role consumer must implement the C<as_string> method.
-
 =head2 resource_name
 
 Name of the task's XML node.
@@ -97,6 +126,17 @@ Name of the task's XML node.
 
 C<id> attribute of this resource.
 
+=head2 as_string
+
+Every role consumer must implement the C<as_string> method.
+
+=head2 content
+
+L<XML::Ant::BuildFile::Resource|XML::Ant::BuildFile::Resource> provides a
+default C<content> attribute, but it only returns C<undef>.  Consumers should
+use the C<around> method modifier to return something else in order to
+support resources with C<refid> attributes
+
 =head1 METHODS
 
 =head2 BUILD
