@@ -13,7 +13,7 @@ use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 package XML::Ant::BuildFile::Task::Copy;
 
 BEGIN {
-    $XML::Ant::BuildFile::Task::Copy::VERSION = '0.209';
+    $XML::Ant::BuildFile::Task::Copy::VERSION = '0.210';
 }
 
 # ABSTRACT: copy task node in an Ant build file
@@ -57,7 +57,7 @@ XML::Ant::BuildFile::Task::Copy - copy task node in an Ant build file
 
 =head1 VERSION
 
-version 0.209
+version 0.210
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,8 @@ version 0.209
 =head1 DESCRIPTION
 
 This is a L<Moose|Moose> type class meant for use with
-L<XML::Rabbit|XML::Rabbit> when processing copy tasks in an Ant build file.
+L<XML::Rabbit|XML::Rabbit> when processing C<< <copy/> >> tasks in an Ant
+build file.
 
 =head1 ATTRIBUTES
 
